<?php

namespace Ems\portalGestor\Service;

use Zeedhi\Framework\Controller\Crud;
use Doctrine\ORM\EntityManager;

use Ems\portalGestor\Util\DateUtil;
use Ems\portalGestor\Repository\ParamOrgRepository;
use Ems\portalGestor\Repository\OperadorRepository;

use Ems\portalGestor\Util\ArrayUtil;

class OperadorService {

    /** @var ParamOrgRepository */
    protected $paramOrgRepository;

    /** @var OperadorRepository */
    protected $operadorRepository;

    public function __construct(
        EntityManager $entityManager,
        OperadorRepository $operadorRepository,
        ParamOrgRepository $paramOrgRepository
    ) {
        $this->entityManager        = $entityManager;
        $this->operadorRepository   = $operadorRepository;
        $this->paramOrgRepository   = $paramOrgRepository;
    }

    public function getDadosOperador(string $cdoperador) {
        try {
            $dadosOperadores = $this->operadorRepository->getDadosOperador($cdoperador);

            if (empty($dadosOperadores) || empty($dadosOperadores[0])) {
                throw new \Exception('Operador não encontrado');
            }

            $operador = $dadosOperadores[0];
            $nrOrg = $operador['NRORG'];

            $isDP = $this->operadorIsDP($nrOrg, $cdoperador);
            $operador['dp'] = $isDP;

            return $operador;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function validaLoginVinculo(string $nrvinculom, string $nrorg) {
        try {
            $loginValido = !empty($this->operadorRepository->validaLogin(
                $nrvinculom,
                $nrorg
            ));
            return $loginValido;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function validaLoginOperador(string $cdoperador) {
        $dadosOperador = $this->getDadosOperador($cdoperador);

        $loginValido = !empty($dadosOperador);
        $dadosOperador['LOGIN_VALIDO'] = $loginValido;

        return $dadosOperador;
    }

    public function getPerfisDeAcesso(
        int $nrOrg,
        string $cdOperador
    ): array {
        $params = [
            'P_NRORG'      => $nrOrg,
            'P_CDOPERADOR' => $cdOperador
        ];

        $perfis = $this->operadorRepository->getPerfisDeAcesso($params);

        $nrPerfis = array_map(function($perfil) {
            return $perfil['NRPERFILACESSO'];
        }, $perfis);

        return $nrPerfis;
    }

    public function operadorIsDP(
        int $nrOrg,
        string $cdOperador
    ): bool {
        $nrPerfis = $this->getPerfisDeAcesso($nrOrg, $cdOperador);

        $paramOrg = $this->paramOrgRepository->getParamOrg($nrOrg);

        $stringPerfisDP = $paramOrg['NRPERFACESSADM'];
        $stringPerfisDP = is_null($stringPerfisDP) ? '' : $stringPerfisDP;

        // $perfisDP = ArrayUtil::fromStringSQL($stringPerfisDP, ',', false);
        $perfisDP = ArrayUtil::fromStringSQL($stringPerfisDP, ArrayUtil::COMMA_ARRAY_STRING_SEPARATOR, false);

        // $perfisDP = ArrayUtil::fromStringSQL($stringPerfisDP);
        $intersection = ArrayUtil::intersection($nrPerfis, $perfisDP);

        $isDP = count($intersection) > 0;

        return $isDP;
    }

    public function getVinculoCdOperador(
        int $nrOrg,
        int $nrVinculo
    ): string {
        $params = [
            'P_NRORG' => $nrOrg,
            'P_NRVINCULO' => $nrVinculo
        ];

        $cdOperador = $this->operadorRepository->getVinculoCdOperador($params);

        return $cdOperador;
    }

    public function vinculoIsDP(
        int $nrOrg,
        int $nrVinculo
    ): bool {
        $cdOperador = $this->getVinculoCdOperador($nrOrg, $nrVinculo);
        $isDP = $this->operadorIsDP($nrOrg, $cdOperador);

        return $isDP;
    }
}